@@ -321,7 +321,7 @@ class Wrapper:
             raise argtypes.ArgTypeNotFoundError("varargs functions not supported")
 
         for param in function_obj.params:
-            if param.pdflt and '|' not in info.parsestr:
+            if param.pdflt != None and '|' not in info.parsestr:
                 info.add_parselist('|', [], [])
             handler = argtypes.matcher.get(param.ptype)
             handler.write_param(param.ptype, param.pname, param.pdflt,
@@ -520,12 +520,12 @@ class Wrapper:
                                { 'name':  method_name,
                                  'cname': '_wrap_' + c_name,
                                  'flags': methflags,
-                                 'docstring': meth.docstring })
+                                 'docstring': 'NULL' })
                 methods_coverage.declare_wrapped()
             except argtypes.ArgTypeError, ex:
                 methods_coverage.declare_not_wrapped()
                 sys.stderr.write('Could not write method %s.%s: %s\n'
-                                % (klass, meth.name, str(ex)))
+                                % (klass, method_name, str(ex)))
 
         # Add GObject virtual method accessors, for chaining to parent
         # virtuals from subclasses
@@ -1330,8 +1330,10 @@ class SourceWriter:
         self.prefix = prefix
         self.fp = fp
 
-    def write(self):
-        self.write_headers()
+    def write(self, py_ssize_t_clean=False):
+        argtypes.py_ssize_t_clean = py_ssize_t_clean
+
+        self.write_headers(py_ssize_t_clean)
         self.write_imports()
         self.write_type_declarations()
         self.write_body()
@@ -1344,11 +1346,28 @@ class SourceWriter:
             self.write_enums()
         self.write_extension_init()
         self.write_registers()
+        
+        argtypes.py_ssize_t_clean = False
 
-    def write_headers(self):
+    def write_headers(self, py_ssize_t_clean):
         self.fp.write('/* -- THIS FILE IS GENERATED - DO NOT EDIT */')
         self.fp.write('/* -*- Mode: C; c-basic-offset: 4 -*- */\n\n')
+        if py_ssize_t_clean:
+            self.fp.write('#define PY_SSIZE_T_CLEAN\n')
         self.fp.write('#include <Python.h>\n\n\n')
+        if py_ssize_t_clean:
+            self.fp.write('''
+
+#if PY_VERSION_HEX < 0x02050000
+typedef int Py_ssize_t;
+#define PY_SSIZE_T_MAX INT_MAX
+#define PY_SSIZE_T_MIN INT_MIN
+typedef inquiry lenfunc;
+typedef intargfunc ssizeargfunc;
+typedef intobjargproc ssizeobjargproc;
+#endif
+
+''')
         self.fp.write(self.overrides.get_headers())
         self.fp.resetline()
         self.fp.write('\n\n')
@@ -1435,6 +1454,11 @@ class SourceWriter:
             'void\n' + self.prefix +
             '_add_constants(PyObject *module, const gchar *strip_prefix)\n{\n')
 
+        self.fp.write(
+            '#ifdef VERSION\n'
+            '    PyModule_AddStringConstant(module, "__version__", VERSION);\n'
+            '#endif\n')
+
         for enum in self.get_enums():
             if enum.typecode is None:
                 for nick, value in enum.values:
@@ -1632,8 +1656,9 @@ def main(argv):
     errorfilename = None
     opts, args = getopt.getopt(argv[1:], "o:p:r:t:D:I:",
                         ["override=", "prefix=", "register=", "outfilename=",
-                         "load-types=", "errorfilename="])
+                         "load-types=", "errorfilename=", "py_ssize_t-clean"])
     defines = {} # -Dkey[=val] options
+    py_ssize_t_clean = False
     for opt, arg in opts:
         if opt in ('-o', '--override'):
             o = override.Overrides(arg)
@@ -1660,6 +1685,8 @@ def main(argv):
                 defines[nameval[0]] = None
         elif opt == '-I':
             defsparser.include_path.insert(0, arg)
+        elif opt == '--py_ssize_t-clean':
+            py_ssize_t_clean = True
     if len(args) < 1:
         print >> sys.stderr, usage
         return 1
@@ -1673,7 +1700,7 @@ def main(argv):
 
     register_types(p)
     sw = SourceWriter(p, o, prefix, FileOutput(sys.stdout, outfilename))
-    sw.write()
+    sw.write(py_ssize_t_clean)
 
     functions_coverage.printstats()
     methods_coverage.printstats()
